The `hs` dataset
================
This test data was obtained from H. Somerville on Feb 22, 2017. It is fake
data which he granted permission to use for the project. It represents
most of the CCSDS oddities that he has encountered.
